/****************************************************************************
** Meta object code from reading C++ file 'Rating.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.4/libdiscover/ReviewsBackend/Rating.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Rating.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6RatingE_t {};
} // unnamed namespace

template <> constexpr inline auto Rating::qt_create_metaobjectdata<qt_meta_tag_ZN6RatingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Rating",
        "sortableRating",
        "rating",
        "ratingPoints",
        "ratingCount",
        "starCounts",
        "std::vector<int>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sortableRating'
        QtMocHelpers::PropertyData<double>(1, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rating'
        QtMocHelpers::PropertyData<float>(2, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ratingPoints'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ratingCount'
        QtMocHelpers::PropertyData<quint64>(4, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'starCounts'
        QtMocHelpers::PropertyData<std::vector<int>>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Rating, qt_meta_tag_ZN6RatingE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Rating::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6RatingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6RatingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6RatingE_t>.metaTypes,
    nullptr
} };

void Rating::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Rating *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->sortableRating(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->rating(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->ratingPoints(); break;
        case 3: *reinterpret_cast<quint64*>(_v) = _t->ratingCount(); break;
        case 4: *reinterpret_cast<std::vector<int>*>(_v) = _t->starCounts(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
